pub struct DocumentedConstants { /* private fields */ }Implementations
Sourceimpl DocumentedConstants
impl DocumentedConstants
Sourcepub fn constant_names(&self) -> &[&'static str]
pub fn constant_names(&self) -> &[&'static str]
Returns all constants names
Sourcepub fn constant_types(&self) -> &[&'static str]
pub fn constant_types(&self) -> &[&'static str]
Returns all constants types
Sourcepub fn constant_values(&self) -> &[&'static str]
pub fn constant_values(&self) -> &[&'static str]
Returns all constants values (raw string)
pub fn constant_docs_raw(&self) -> &[&[&'static str]]
Sourcepub fn constant_docs(&self) -> Vec<Vec<&'static str>>
pub fn constant_docs(&self) -> Vec<Vec<&'static str>>
Returns all constants docstrings, one line being one string
Sourcepub fn commented_constants(&self) -> String
pub fn commented_constants(&self) -> String
Returns string where each constant is shown with its type and docstring