pub trait DocumentedEnum {
// Required methods
fn enum_docs_raw() -> Vec<&'static str>;
fn variant_docs_raw() -> Vec<Vec<&'static str>>;
fn variant_names() -> Vec<&'static str>;
// Provided methods
fn enum_docs() -> Vec<&'static str> { ... }
fn variant_docs() -> Vec<Vec<&'static str>> { ... }
fn commented_variants() -> String { ... }
}Required Methods
fn enum_docs_raw() -> Vec<&'static str>
fn variant_docs_raw() -> Vec<Vec<&'static str>>
Sourcefn variant_names() -> Vec<&'static str>
fn variant_names() -> Vec<&'static str>
Returns all variants of the enum
Provided Methods
Sourcefn variant_docs() -> Vec<Vec<&'static str>>
fn variant_docs() -> Vec<Vec<&'static str>>
Returns all docstrings of each variant, each line is a separate string
Sourcefn commented_variants() -> String
fn commented_variants() -> String
Returns a string shownig all variants and their docstrings
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.